<?php
namespace wcf\acp\action;
use wcf\action\AbstractAction;
use wcf\data\didyouknow\DidYouKnowEntryList;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\util\StringUtil;
use wcf\system\WCF;

/**
 * Exports the did you know entrys to an XML.
 * 
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	acp.action
 * @category 	Community Framework
 */
class DidYouKnowExportAction extends AbstractAction {
	/**
	 * @see wcf\action\AbstractAction::$neededPermissions
	 */
	public $neededPermissions = array('admin.didYouKnow.canAddEntry');

	/**
	 * @see wcf\action\IAction::execute();
	 */
	public function execute() {
		parent::execute();
		$conditions = new PreparedStatementConditionBuilder();
		
		// header
		@header('Content-type: text/xml');

		// file name
		@header('Content-disposition: attachment; filename="didyouknow_'.TIME_NOW.'.xml"');
			
		// no cache headers
		@header('Pragma: no-cache');
		@header('Expires: 0');
		
		// bom
		echo "\xEF\xBB\xBF";
		
		// header
		echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<didyouknow xmlns=\"http://xsd.wbb-world.de\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://xsd.wbb-world.de http://xsd.wbb-world.de/maelstrom/didyouknow.xsd\">\n";
		echo "\t<entrys>\n";
			
		$entryList = new DidYouKnowEntryList();
		$entryList->sqlLimit = 0;
		$entryList->readObjects();
		
		// identify i18n entrys
		$languageVariables = array();
		foreach ($entryList->getObjects() as $object) {
			if (preg_match('~wcf.didyouknow.message.text\d+~', $object->message)) {
				$languageVariables[] = $object->message;
			}
		}
		
		if (!empty($languageVariables)) {
			$conditions = new PreparedStatementConditionBuilder();
			$conditions->add("languageItem IN (?)", array($languageVariables));
		
			// get language variables for i18n entrys
			$sql = "SELECT	item.languageItem, item.languageItemValue, language.languageCode	
					FROM	wcf".WCF_N."_language_item item
					LEFT JOIN wcf".WCF_N."_language language ON (language.languageID = item.languageID)
					".$conditions;
			$statement = WCF::getDB()->prepareStatement($sql);
				$statement->execute($conditions->getParameters());
			while ($row = $statement->fetchArray()) {
				$languageVariables[$row['languageItem']][$row['languageCode']] = $row['languageItemValue'];
			}
		}
			
		foreach ($entryList->getObjects() as $object) {
			echo "\t\t<entry>\n";
			if (in_array($object->message, $languageVariables)) {
				foreach ($languageVariables[$object->message] as $languageCode => $value) {
					echo "\t\t\t<message languageCode=\"".$languageCode."\"><![CDATA[".StringUtil::escapeCDATA($value)."]]></message>\n";	
				}
			} 
			else {
				echo "\t\t\t<message><![CDATA[".StringUtil::escapeCDATA($object->message)."]]></message>\n";	
			}
			echo "\t\t\t<isDisabled>".StringUtil::escapeCDATA($object->isDisabled)."</isDisabled>\n";	
			echo "\t\t\t<priority>".StringUtil::escapeCDATA($object->priority)."</priority>\n";	
			echo "\t\t\t<enableSmilies>".StringUtil::escapeCDATA($object->enableSmilies)."</enableSmilies>\n";	
			echo "\t\t\t<enableHtml>".StringUtil::escapeCDATA($object->enableHtml)."</enableHtml>\n";	
			echo "\t\t\t<enableBBCodes>".StringUtil::escapeCDATA($object->enableBBCodes)."</enableBBCodes>\n";	
			echo "\t\t</entry>\n";
		}
		
		echo "\t</entrys>\n";
		// footer
		echo '</didyouknow>';
		
		$this->executed();
		exit;
	}
}