<?php
namespace wcf\data\didyouknow;
use wcf\data\DatabaseObject;
use wcf\system\language\LanguageFactory;
use wcf\system\application\ApplicationHandler;
use wcf\system\WCF;
use wcf\util\StringUtil;
use wcf\system\bbcode\MessageParser;

/**
 * Represents a did you know entry.
 * 
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	data.didyouknow
 * @category 	Community Framework
 */
class DidYouKnowEntry extends DatabaseObject {

	/**
	 * @see	wcf\data\DatabaseObject::$databaseTableName
	 */
	protected static $databaseTableName = 'didyouknow';
	
	/**
	 * @see	wcf\data\DatabaseObject::$databaseTableIndexName
	 */
	protected static $databaseTableIndexName = 'dykID';
	
	/**
	 * Returns the formatted message.
	 *
	 * @param	string	$outputType
	 * @return	string	$newText
	 */
	public function getFormattedText($message = null, $outputType = 'text/html') {
		$application = ApplicationHandler::getInstance()->getActiveApplication();
		
		$messageDataSearch = array(
			'{$pageTitle}',
			'{$pageUrl}',
			'{$username}',
			'{$userID}',
			'{$adminMail}'
		);
		$messageDataReplace = array(
			WCF::getLanguage()->get(PAGE_TITLE),
			$application->getPageURL(),
			WCF::getUser()->username,
			WCF::getUser()->userID,
			MAIL_ADMIN_ADDRESS
		);
		
		
		// replace language vars and get i18n value
		$message = WCF::getLanguage()->get((($message == null)?$this->message:$message));
		$message = str_replace($messageDataSearch, $messageDataReplace, $message);
	
		// parse message
		$messageParser = MessageParser::getInstance();
		$messageParser->setOutputType($outputType);
		return $messageParser->parse($message, $this->enableSmilies, $this->enableHtml, $this->enableBBCodes, false);
	}

		/**
	 * Returns the shortened message.
	 *
	 * @param	integer	$length
	 * @return	string	$message
	 */
	public function getShortenedMessage($length = 200) {
		// shorten text
		if (mb_strlen($this->message) > $length) {
			$length -= 3;
			$string = preg_replace('/\s+?(\S+)?$/', '', mb_substr($this->message, 0, $length + 1));
			$message = mb_substr($string, 0, $length).'...';
		}
		else {
   			$message = $this->message;
		}
		
		return $this->getFormattedText($message, 'text/plain');
	}

	/**
	 * Returns the message.
	 *
	 * @return	string	$message
	 */
	public function getMessage($outputType = 'text/html') {
		return WCF::getLanguage()->get($this->message);
	}

	/**
	 * Returns the display settings.
	 *
	 * @return	array	$settings
	 */
	public function getDisplaySettings() {
		if ($this->useOwnSettings) {
			return array(
				'align' => $this->align
			);
		}
		else {
			return array(
				'align' => DIDYOUKNOW_GLOBAL_ALIGN
			);
		}
	}
}